package dareka;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

public class Main {
    // public so that external tools can read.
    public static final String VER_STRING = "NicoCache v0.12";
    // accessor for avoiding static link
    public static String getVersion() {
        return VER_STRING;
    }

    private static Server server;

    public static void stop() {
        if (server != null) {
            server.stop();
        }
    }

    /**
     * @param args
     * @throws IOException
     */
    public static void main(String[] args) throws IOException {
        File configFile = new File("config.properties");
        Config config = new Config();
        if (configFile.exists()) {
            Properties p = new Properties();

            FileInputStream in = new FileInputStream(configFile);
            try { // ensure closing in
                p.load(in);
            } finally {
                in.close();
            }

            config.setListenPort(Integer.valueOf(p.getProperty("listenPort",
                    "8080")));
            config.setProxyHost(p.getProperty("proxyHost", ""));
            config.setProxyPort(Integer.valueOf(p.getProperty("proxyPort",
                    "8081")));
            config.setTitle(Boolean.valueOf(p.getProperty("title", "true")));
        } else {
            config.setListenPort(8080);
            config.setProxyHost("");
            config.setProxyPort(8081);
            config.setTitle(true);

            Properties p = new Properties();
            p.setProperty("listenPort", Integer
                    .toString(config.getListenPort()));
            p.setProperty("proxyHost", config.getProxyHost());
            p.setProperty("proxyPort", Integer.toString(config.getProxyPort()));
            p.setProperty("title", Boolean.toString(config.isTitle()));

            FileOutputStream out = new FileOutputStream(configFile);
            try { // ensure closing out
                p.store(out, "NicoCache config file");
            } finally {
                out.close();
            }
        }

        System.out.println(VER_STRING);
        System.out.println("port=" + config.getListenPort());
        if (config.getProxyHost().equals("")) {
            System.out.println("direct mode (no secondary proxy)");
        } else {
            System.out.println("proxy host=" + config.getProxyHost());
            System.out.println("proxy port=" + config.getProxyPort());
        }
        System.out.println("title=" + config.isTitle());

        Cache.init();
        Cache.cleanup();
        System.out.printf("total cache size=%,dbytes\n", Cache.size());

        server = new Server(config);

        server.start();
    }

}
